# spectre-core

## Description
  
:loudspeaker: **This project is under active development. Contributors welcome.** :loudspeaker:  

```spectre-core``` provides a SDR receiver-agnostic digital signal processing framework. It is the core Python package used by the [`spectre`](https://github.com/jcfitzpatrick12/spectre.git) program.  


## Installation
Typically, installation of ```spectre-core``` is managed in the ```spectre``` back-end. In any case, if you would like, simply call:  
```pip install spectre-core```. 

Alternatively, you can clone the repository in your preferred directory:  
```git clone https://github.com/jcfitzpatrick12/spectre-core.git && cd spectre-core```  

Then run:  
```pip install -e .```


## Contributing
This repository is in active development. If you are interested, feel free to contact  jcfitzpatrick12@gmail.com :)